==> jc-1.4.0.tar.gz: polyglot/frontend/SourceJob.h <==
// public class polyglot.frontend.SourceJob

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 42e687805b457724 polyglot_frontend_Job
// @dep_class 6b393ef3f88ef5d0 polyglot_frontend_SourceJob

// header file dependencies
// @dep_header polyglot_frontend_Job

#include "polyglot/frontend/Job.h"

#ifndef _JC_polyglot_frontend_SourceJob_H_
#define _JC_polyglot_frontend_SourceJob_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_frontend_JobExt$object;
struct _jc_polyglot_frontend_Source$object;
struct _jc_polyglot_frontend_SourceJob$object;

// Typedefs
typedef struct _jc_polyglot_frontend_SourceJob$sub_refs	_jc_polyglot_frontend_SourceJob$sub_refs;
typedef struct _jc_polyglot_frontend_SourceJob$sub_nonrefs	_jc_polyglot_frontend_SourceJob$sub_nonrefs;
typedef struct _jc_polyglot_frontend_SourceJob$refs	_jc_polyglot_frontend_SourceJob$refs;
typedef struct _jc_polyglot_frontend_SourceJob$nonrefs	_jc_polyglot_frontend_SourceJob$nonrefs;
typedef struct _jc_polyglot_frontend_SourceJob$object	_jc_polyglot_frontend_SourceJob$object;

typedef const struct _jc_polyglot_frontend_SourceJob$vmethods	_jc_polyglot_frontend_SourceJob$vmethods;
typedef const struct _jc_polyglot_frontend_SourceJob$vtable	_jc_polyglot_frontend_SourceJob$vtable;
typedef const struct _jc_polyglot_frontend_SourceJob$vtype	_jc_polyglot_frontend_SourceJob$vtype;

// Constructors
extern void _jc_polyglot_frontend_SourceJob$method$_init$30e41861df0225d5(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_frontend_Source$object *, struct _jc_object *);

// Virtual methods
extern void _jc_polyglot_frontend_SourceJob$method$addDependency$828aadfd05bceaa5(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *, struct _jc_polyglot_frontend_Source$object *);
extern struct _jc_object *_jc_polyglot_frontend_SourceJob$method$dependencies$3bf3a2602975a907(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *);
extern struct _jc_object *_jc_polyglot_frontend_SourceJob$method$getPasses$e5b4184d264aa29f(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *);
extern struct _jc_polyglot_frontend_Source$object *_jc_polyglot_frontend_SourceJob$method$source$998a5a64aa67515f(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *);
extern struct _jc_polyglot_frontend_SourceJob$object *_jc_polyglot_frontend_SourceJob$method$sourceJob$2fc26d39f6f66cf4(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_SourceJob$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_SourceJob$method_info$addDependency$828aadfd05bceaa5;
extern _jc_method _jc_polyglot_frontend_SourceJob$method_info$dependencies$3bf3a2602975a907;
extern _jc_method _jc_polyglot_frontend_SourceJob$method_info$getPasses$e5b4184d264aa29f;
extern _jc_method _jc_polyglot_frontend_SourceJob$method_info$source$998a5a64aa67515f;
extern _jc_method _jc_polyglot_frontend_SourceJob$method_info$sourceJob$2fc26d39f6f66cf4;
extern _jc_method _jc_polyglot_frontend_SourceJob$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_frontend_SourceJob$vmethods {
	void	(*addDependency$828aadfd05bceaa5)(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *, struct _jc_polyglot_frontend_Source$object *);
	struct _jc_object	*(*dependencies$3bf3a2602975a907)(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *);
	struct _jc_object	*(*getPasses$e5b4184d264aa29f)(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *);
	struct _jc_polyglot_frontend_Source$object	*(*source$998a5a64aa67515f)(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *);
	struct _jc_polyglot_frontend_SourceJob$object	*(*sourceJob$2fc26d39f6f66cf4)(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *);
};

// Vtable
struct _jc_polyglot_frontend_SourceJob$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_Job$vmethods	polyglot_frontend_Job;
	_jc_polyglot_frontend_SourceJob$vmethods	polyglot_frontend_SourceJob;
};

// Vtype
struct _jc_polyglot_frontend_SourceJob$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_SourceJob$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_SourceJob$sub_refs {
	struct _jc_polyglot_frontend_Source$object	*source;
	struct _jc_object	*dependencies;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_SourceJob$refs {
    _jc_polyglot_frontend_SourceJob$sub_refs	polyglot_frontend_SourceJob;
    _jc_polyglot_frontend_Job$sub_refs	polyglot_frontend_Job;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_SourceJob$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_SourceJob$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_Job$sub_nonrefs	polyglot_frontend_Job;
    _jc_polyglot_frontend_SourceJob$sub_nonrefs	polyglot_frontend_SourceJob;
};

// Object instance structure
struct _jc_polyglot_frontend_SourceJob$object {
	_jc_polyglot_frontend_SourceJob$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_SourceJob$vtype	*vtype;
	_jc_polyglot_frontend_SourceJob$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_SourceJob$vtype _jc_polyglot_frontend_SourceJob$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_SourceJob, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_SourceJob$class_object;

#endif	/* _JC_polyglot_frontend_SourceJob_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/SourceJob.h <==
// public class polyglot.frontend.SourceJob

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 42e687805b457724 polyglot_frontend_Job
// @dep_class 6b393ef3f88ef5d0 polyglot_frontend_SourceJob

// header file dependencies
// @dep_header polyglot_frontend_Job

#include "polyglot/frontend/Job.h"

#ifndef _JC_polyglot_frontend_SourceJob_H_
#define _JC_polyglot_frontend_SourceJob_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_frontend_JobExt$object;
struct _jc_polyglot_frontend_Source$object;
struct _jc_polyglot_frontend_SourceJob$object;

// Typedefs
typedef struct _jc_polyglot_frontend_SourceJob$sub_refs	_jc_polyglot_frontend_SourceJob$sub_refs;
typedef struct _jc_polyglot_frontend_SourceJob$sub_nonrefs	_jc_polyglot_frontend_SourceJob$sub_nonrefs;
typedef struct _jc_polyglot_frontend_SourceJob$refs	_jc_polyglot_frontend_SourceJob$refs;
typedef struct _jc_polyglot_frontend_SourceJob$nonrefs	_jc_polyglot_frontend_SourceJob$nonrefs;
typedef struct _jc_polyglot_frontend_SourceJob$object	_jc_polyglot_frontend_SourceJob$object;

typedef const struct _jc_polyglot_frontend_SourceJob$vmethods	_jc_polyglot_frontend_SourceJob$vmethods;
typedef const struct _jc_polyglot_frontend_SourceJob$vtable	_jc_polyglot_frontend_SourceJob$vtable;
typedef const struct _jc_polyglot_frontend_SourceJob$vtype	_jc_polyglot_frontend_SourceJob$vtype;

// Constructors
extern void _jc_polyglot_frontend_SourceJob$method$_init$30e41861df0225d5(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_frontend_Source$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_polyglot_frontend_SourceJob$method$addDependency$828aadfd05bceaa5(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *, struct _jc_polyglot_frontend_Source$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_frontend_SourceJob$method$dependencies$3bf3a2602975a907(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_frontend_SourceJob$method$getPasses$e5b4184d264aa29f(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_frontend_Source$object *_jc_polyglot_frontend_SourceJob$method$source$998a5a64aa67515f(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_frontend_SourceJob$object *_jc_polyglot_frontend_SourceJob$method$sourceJob$2fc26d39f6f66cf4(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_SourceJob$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_SourceJob$method_info$addDependency$828aadfd05bceaa5;
extern _jc_method _jc_polyglot_frontend_SourceJob$method_info$dependencies$3bf3a2602975a907;
extern _jc_method _jc_polyglot_frontend_SourceJob$method_info$getPasses$e5b4184d264aa29f;
extern _jc_method _jc_polyglot_frontend_SourceJob$method_info$source$998a5a64aa67515f;
extern _jc_method _jc_polyglot_frontend_SourceJob$method_info$sourceJob$2fc26d39f6f66cf4;
extern _jc_method _jc_polyglot_frontend_SourceJob$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_frontend_SourceJob$vmethods {
	void	(*addDependency$828aadfd05bceaa5)(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *, struct _jc_polyglot_frontend_Source$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*dependencies$3bf3a2602975a907)(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPasses$e5b4184d264aa29f)(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_frontend_Source$object	*(*source$998a5a64aa67515f)(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_frontend_SourceJob$object	*(*sourceJob$2fc26d39f6f66cf4)(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_frontend_SourceJob$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_frontend_SourceJob$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_Job$vmethods	polyglot_frontend_Job;
	_jc_polyglot_frontend_SourceJob$vmethods	polyglot_frontend_SourceJob;
};

// Vtype
struct _jc_polyglot_frontend_SourceJob$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_SourceJob$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_SourceJob$sub_refs {
	struct _jc_polyglot_frontend_Source$object	*source;
	struct _jc_object	*dependencies;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_SourceJob$refs {
    _jc_polyglot_frontend_SourceJob$sub_refs	polyglot_frontend_SourceJob;
    _jc_polyglot_frontend_Job$sub_refs	polyglot_frontend_Job;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_SourceJob$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_SourceJob$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_Job$sub_nonrefs	polyglot_frontend_Job;
    _jc_polyglot_frontend_SourceJob$sub_nonrefs	polyglot_frontend_SourceJob;
};

// Object instance structure
struct _jc_polyglot_frontend_SourceJob$object {
	_jc_polyglot_frontend_SourceJob$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_SourceJob$vtype	*vtype;
	_jc_polyglot_frontend_SourceJob$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_SourceJob$vtype _jc_polyglot_frontend_SourceJob$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_SourceJob, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_SourceJob$class_object;

#endif	/* _JC_polyglot_frontend_SourceJob_H_ */
